@@ -232,6 +232,7 @@ def process_includes(code, input_file):
 
     return header_code, code_without_includes
 
+
 def execute_code_temporarily(code):
     with tempfile.TemporaryDirectory() as tmpdir:
         temp_file_path = os.path.join(tmpdir, "compiled_repy.py")
@@ -243,6 +244,7 @@ def execute_code_temporarily(code):
             print(f"Error during execution: {e}")
             print(f"You can view the generated file at {(temp_file_path)}")
 
+
 def main():
     parser = argparse.ArgumentParser(description="Compile REPY files.")
     parser.add_argument("filename", help="The REPY file to compile.")
@@ -253,23 +255,64 @@ def main():
     if not os.path.exists(input_file):
         print(f"Error: The file {input_file} does not exist.")
         return
+    if input_file.endswith('repyconfig.toml'):
+        import tomllib as toml
+        import fnmatch
+        with open(input_file, "rb") as file:
+            data = toml.load(file)
+        try:
+            compile_value = data["config"]["compile"]
+        except:
+            compile_value = "null"
+            print("[WARNING] Error reading compile value from config")
+        try:
+            exclude_files = data["config"]["exclude"]
+        except:
+            exclude_files = []
+            print("[WARNING] No excluded files found in config")
+        if compile_value == 'all':
+            extension = ".repy"
+            matching_files = []
+            for dirpath, _, filenames in os.walk("."):
+                for filename in filenames:
+                    if filename.lower().endswith(extension.lower()):
+                        file_path_temp = os.path.join(dirpath, filename)
+                        if any(fnmatch.fnmatch(file_path_temp, pattern) for pattern in exclude_files):
+                            continue
+                        matching_files.append(file_path_temp)
+            for file_path_z in matching_files:
+                with open(file_path_z, 'r') as z:
+                    source_code_z = z.read()
 
-    with open(input_file, 'r') as f:
-        source_code = f.read()
+                header_code_z, code_without_includes_z = process_includes(source_code_z, file_path_z)
 
-    header_code, code_without_includes = process_includes(
-        source_code, input_file)
+                python_code_z = parse_repython(code_without_includes_z)
 
-    python_code = parse_repython(code_without_includes)
+                final_code_z = header_code_z + python_code_z
 
-    final_code = header_code + python_code
+                output_file_z = os.path.splitext(file_path_z)[0] + '.py'
 
-    output_file = os.path.splitext(input_file)[0] + '.py'
+                with open(output_file_z, 'w') as z:
+                    z.write(final_code_z)
+                print(f"[DEBUG] Successfully compiled {file_path_z} to {output_file_z}")
+    else:
+        with open(input_file, 'r') as f:
+            source_code = f.read()
 
-    with open(output_file, 'w') as f:
-        f.write(final_code)
+        header_code, code_without_includes = process_includes(
+            source_code, input_file)
+
+        python_code = parse_repython(code_without_includes)
+
+        final_code = header_code + python_code
+
+        output_file = os.path.splitext(input_file)[0] + '.py'
+
+        with open(output_file, 'w') as f:
+            f.write(final_code)
+
+        print(f"[DEBUG] Successfully compiled {input_file} to {output_file}")
 
-    print(f"Successfully compiled {input_file} to {output_file}")     
 
 def launch():
     parser = argparse.ArgumentParser(description="Preview REPY execution.")
@@ -300,7 +343,4 @@ def launch():
 
 
 if __name__ == "__main__":
-    main(1)
-
-if __name__ == "__launch__":
-    main(2)
\ No newline at end of file
+    main()
